﻿using System.ComponentModel;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Diagnostics;

namespace CodeCamp.Common.Controls
{
	public partial class ErrorStatus : UserControl
	{
		public ErrorStatus()
		{
			InitializeComponent();
			SetBinding(MyDataContextProperty, new Binding());
		}

		public static readonly DependencyProperty MyDataContextProperty =
			DependencyProperty.Register("MyDataContext",
										typeof(object),
										typeof(ErrorStatus),
										new PropertyMetadata(DataContextChanged));

		public static readonly DependencyProperty PropertyNameProperty =
			DependencyProperty.Register("PropertyName",
										typeof(string),
										typeof(ErrorStatus),
										null);

		private static void DataContextChanged(object sender, DependencyPropertyChangedEventArgs e)
		{
			INotifyPropertyChanged property;
			ErrorStatus errorStatus = (ErrorStatus)sender;

			property = e.OldValue as INotifyPropertyChanged;
			if (property != null)
				property.PropertyChanged -= errorStatus.property_PropertyChanged;

			property = e.NewValue as INotifyPropertyChanged;
			if (property != null)
				property.PropertyChanged += errorStatus.property_PropertyChanged;

			errorStatus.UpdateStatus(e.NewValue);
		}

		public string PropertyName
		{
			get { return (string)GetValue(PropertyNameProperty); }
			set { SetValue(PropertyNameProperty, value); }
		}

		private void property_PropertyChanged(object sender, PropertyChangedEventArgs e)
		{
			if (e.PropertyName == PropertyName)
				UpdateStatus(sender);
		}

		private void UpdateStatus(object sender)
		{
			IDataErrorInfo info = sender as IDataErrorInfo;
			if (info != null)
			{
				string errorText = info[PropertyName];
				if (string.IsNullOrEmpty(errorText))
					Opacity = 0;
				else
					Opacity = 100;

				ToolTipService.SetToolTip(this, errorText);
			}
		}
	}
}
