﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Runtime.Serialization;
using System.Text;

namespace CodeCamp.Model
{
	public enum MessageFields
	{
		Content,
		Date
	}

	[DataContract]
	public class Message : INotifyPropertyChanged, IDataErrorInfo
	{
		private Dictionary<String, String> m_Errors;

		private String m_Content;
		[DataMember]
		public String Content
		{
			get { return m_Content; }
			set
			{
				m_Content = value;
				Validate(MessageFields.Content);
				NotifyPropertyChanged(MessageFields.Content);
			}
		}

		private DateTime m_Date;
		[DataMember]
		public DateTime Date
		{
			get { return m_Date; }
			set
			{
				m_Date = value;
				Validate(MessageFields.Date);
				NotifyPropertyChanged(MessageFields.Date);
			}
		}

		#region INotifyPropertyChanged Members

		public event PropertyChangedEventHandler PropertyChanged;

		private void NotifyPropertyChanged(MessageFields name)
		{
			if (this.PropertyChanged == null)
				return;

			this.PropertyChanged(this, new PropertyChangedEventArgs(name.ToString()));
		}

		#endregion

		#region IDataErrorInfo Members

		public string Error
		{
			get
			{
				StringBuilder result = new StringBuilder();
				foreach (var item in m_Errors)
				{
					if (!String.IsNullOrEmpty(item.Value))
						result.AppendLine(item.Value);
				}

				return result.ToString();
			}
		}

		public string this[string columnName]
		{
			get
			{
				string result = null;

				m_Errors.TryGetValue(columnName, out result);

				return result;
			}
		}

		private void Validate(MessageFields propertyName)
		{
			if (m_Errors == null)
				m_Errors = new Dictionary<string, string>();

			if (m_Errors.ContainsKey(propertyName.ToString()))
				m_Errors.Remove(propertyName.ToString());

			switch (propertyName)
			{
				case MessageFields.Content:
					if (this.Content.IndexOf('<') != -1)
						m_Errors.Add(MessageFields.Content.ToString(), "Tsk, Tsk, no html tags please!");
					break;
				case MessageFields.Date:
					break;
			}
		}

		#endregion
	}
}
